-- Pull in the wezterm API
local wezterm = require 'wezterm'

-- This will hold the configuration.
local config = wezterm.config_builder()
local act = wezterm.action

-- This is where you actually apply your config choices
config.ssh_domains = {
  {
    -- This name identifies the domain
    name = 'home',
    -- The hostname or address to connect to. Will be used to match settings
    -- from your ssh config file
    remote_address = '192.168.1.20',
    -- The username to use on the remote host
    username = 'anton',
  },
}
config.keys = {
  { key = 'U', mods = 'CTRL|SHIFT', action = act.AttachDomain 'devhost' },
  -- Detaches the domain associated with the current pane
  {
    key = 'D',
    mods = 'CTRL|SHIFT',
    action = act.DetachDomain 'CurrentPaneDomain',
  },
  -- Detaches the "devhost" domain
  {
    key = 'E',
    mods = 'CTRL|SHIFT',
    action = act.DetachDomain { DomainName = 'devhost' },
  },
}

config.window_frame = {
  -- The font used in the tab bar.
  -- Roboto Bold is the default; this font is bundled
  -- with wezterm.
  -- Whatever font is selected here, it will have the
  -- main font setting appended to it to pick up any
  -- fallback fonts you may have used there.
  font = wezterm.font { family = 'Jetbrains Mono', weight = 700 },

  -- The size of the font in the tab bar.
  -- Default to 10.0 on Windows but 12.0 on other systems
  font_size = 15.0,

  -- The overall background color of the tab bar when
  -- the window is focused
  active_titlebar_bg = '#333333',

  -- The overall background color of the tab bar when
  -- the window is not focused
  inactive_titlebar_bg = '#333333',
}

config.colors = {
  tab_bar = {
    -- The color of the inactive tab bar edge/divider
    inactive_tab_edge = '#575757',
  },
}


-- For example, changing the color scheme: ==>  A!=B
config.color_scheme = 'Galaxy'
config.font = wezterm.font('Jetbrains Mono', { weight = 600 })
config.freetype_load_target = 'Light'
config.font_size = 16
config.line_height = 1.05
config.harfbuzz_features = { 'calt=1', 'clig=0', 'liga=0' }
-- and finally, return the configuration to wezterm
return config
